==> restaf-server-4.5.0.tgz: package/app.js <==
#!/usr/bin/env node
/*
 *  ------------------------------------------------------------------------------------
 *  * Copyright (c) SAS Institute Inc.
 *  *  Licensed under the Apache License, Version 2.0 (the "License");
 *  * you may not use this file except in compliance with the License.
 *  * You may obtain a copy of the License at
 *  *
 *  * http://www.apache.org/licenses/LICENSE-2.0
 *  *
 *  *  Unless required by applicable law or agreed to in writing, software
 *  * distributed under the License is distributed on an "AS IS" BASIS,
 *  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  * See the License for the specific language governing permissions and
 *  limitations under the License.
 * ----------------------------------------------------------------------------------------
 *
 */


'use strict';

debugger;
let rafserver = require ('./lib/restaf-server');
let rafEnv    = (process.argv.length === 3) ? process.argv [ 2 ] : null ;
console.log((rafEnv === null) ? 'NOTE: Using settings from environment variables': `NOTE: env file is: ${rafEnv}`);
rafserver.UIapp (getCustomHandler(), null, rafEnv);

function getCustomHandler () {
    let handler =
    [
        {
            method: [ 'GET' ],
            path  : `/appenv`,
            config: {
                auth   : false,
                cors   : true,
                handler: getAppEnv

            }
       }

    ];
    return handler;
    }

    async function getAppEnv (req, h) {
        let env;
        if ( process.env.AUTHFLOW === 'implicit') {
           env = `
    
            let LOGONPAYLOAD = {
                authType: '${process.env.AUTHFLOW}',
                host    : '${process.env.VIYA_SERVER}',
                clientID: '${process.env.CLIENTID}',
                redirect: '${process.env.APPNAME}/${process.env.REDIRECT}'
            };
         `
        } else {
            env = `
                let LOGONPAYLOAD = {
                    authType: '${process.env.AUTHFLOW}',
                    /*host    : '${process.env.VIYA_SERVER}',*/
                    passThru: '${process.env.VIYA_SERVER}'
                };
                `;
        }
        console.log( env );
    return env;
    }

==> restaf-server-6.0.0.tgz: package/app.js <==
#!/usr/bin/env node
/*
 *  ------------------------------------------------------------------------------------
 *  * Copyright (c) SAS Institute Inc.
 *  *  Licensed under the Apache License, Version 2.0 (the "License");
 *  * you may not use this file except in compliance with the License.
 *  * You may obtain a copy of the License at
 *  *
 *  * http://www.apache.org/licenses/LICENSE-2.0
 *  *
 *  *  Unless required by applicable law or agreed to in writing, software
 *  * distributed under the License is distributed on an "AS IS" BASIS,
 *  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  * See the License for the specific language governing permissions and
 *  limitations under the License.
 * ----------------------------------------------------------------------------------------
 *
 */


'use strict';

debugger;
let rafserver = require ('./lib/index.js');

let rafEnv    = (process.argv.length === 3) ? process.argv [ 2 ] : null ;
console.log((rafEnv === null) ? 'NOTE: Using settings from environment variables': `NOTE: env file is: ${rafEnv}`);
rafserver.UIapp (getCustomHandler(), null, rafEnv);

function getCustomHandler () {
    let handler =
    [
        {
            method: [ 'GET' ],
            path  : `/appenv`,
            config: {
                auth   : false,
                cors   : true,
                handler: getAppEnv

            }
       }

    ];
    return handler;
    }

    async function getAppEnv (req, h) {
        let env;
        console.log( 'in default appenv');
        if ( process.env.AUTHFLOW === 'implicit') {
           env = `
    
            let LOGONPAYLOAD = {
                authType: '${process.env.AUTHFLOW}',
                host    : '${process.env.VIYA_SERVER}',
                clientID: '${process.env.CLIENTID}',
                redirect: '${process.env.APPNAME}/${process.env.REDIRECT}'
            };
            let APPENV = {
                info: 'implicit case'
            }
         `
        } else {
            env = `
                let LOGONPAYLOAD = {
                    authType: '${process.env.AUTHFLOW}',
                    /*host    : '${process.env.VIYA_SERVER}',*/
                    passThru: '${process.env.VIYA_SERVER}'
                };
                let APPENV = {
                    info: 'non-implicit case'
                }
                `;
        }
        console.log( env );
    return env;
    }
